aboutsummaryrefslogtreecommitdiffstats
path: root/vm/vmimpl/vmimpl.go
diff options
context:
space:
mode:
Diffstat (limited to 'vm/vmimpl/vmimpl.go')
-rw-r--r--vm/vmimpl/vmimpl.go8
1 files changed, 4 insertions, 4 deletions
diff --git a/vm/vmimpl/vmimpl.go b/vm/vmimpl/vmimpl.go
index 2e3833d89..4565d173e 100644
--- a/vm/vmimpl/vmimpl.go
+++ b/vm/vmimpl/vmimpl.go
@@ -33,7 +33,7 @@ type Instance interface {
// Run runs cmd inside of the VM (think of ssh cmd).
// outc receives combined cmd and kernel console output.
// errc receives either command Wait return error or vmimpl.TimeoutErr.
// Command is terminated after timeout. Send on the stop chan can be used to terminate it earlier.
Run(timeout time.Duration, stop <-chan bool, command string) (outc <-chan []byte, errc <-chan error, err error)
@@ -50,8 +50,8 @@ type Env struct {
Arch string // target arch
Workdir string
Image string
- SshKey string
- SshUser string
+ SSHKey string
+ SSHUser string
Debug bool
Config []byte // json-serialized VM-type-specific config
}
@@ -87,7 +87,7 @@ func Register(typ string, ctor ctorFunc) {
var (
// Close to interrupt all pending operations in all VMs.
Shutdown = make(chan struct{})
- TimeoutErr = errors.New("timeout")
+ ErrTimeout = errors.New("timeout")
ctors = make(map[string]ctorFunc)
)
@@ -33,7 +33,7 @@ type Instance interface {
// Run runs cmd inside of the VM (think of ssh cmd).
// outc receives combined cmd and kernel console output.
- // errc receives either command Wait return error or vmimpl.TimeoutErr.
+ // errc receives either command Wait return error or vmimpl.ErrTimeout.
// Command is terminated after timeout. Send on the stop chan can be used to terminate it earlier.
Run(timeout time.Duration, stop <-chan bool, command string) (outc <-chan []byte, errc <-chan error, err error)